# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: core/mgmt/v1beta/metric.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x63ore/mgmt/v1beta/metric.proto\x12\x10\x63ore.mgmt.v1beta\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe5\x03\n\x15PipelineTriggerRecord\x12=\n\x0ctrigger_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0btriggerTime\x12.\n\x13pipeline_trigger_id\x18\x02 \x01(\tR\x11pipelineTriggerId\x12\x1f\n\x0bpipeline_id\x18\x03 \x01(\tR\npipelineId\x12!\n\x0cpipeline_uid\x18\x04 \x01(\tR\x0bpipelineUid\x12\x39\n\x0ctrigger_mode\x18\x05 \x01(\x0e\x32\x16.core.mgmt.v1beta.ModeR\x0btriggerMode\x12\x38\n\x15\x63ompute_time_duration\x18\x06 \x01(\x02\x42\x04\xe2\x41\x01\x03R\x13\x63omputeTimeDuration\x12\x36\n\x06status\x18\x07 \x01(\x0e\x32\x18.core.mgmt.v1beta.StatusB\x04\xe2\x41\x01\x03R\x06status\x12\x34\n\x13pipeline_release_id\x18\x08 \x01(\tB\x04\xe2\x41\x01\x03R\x11pipelineReleaseId\x12\x36\n\x14pipeline_release_uid\x18\t \x01(\tB\x04\xe2\x41\x01\x03R\x12pipelineReleaseUid\"\xc6\x02\n\x1aPipelineTriggerTableRecord\x12\x1f\n\x0bpipeline_id\x18\x01 \x01(\tR\npipelineId\x12!\n\x0cpipeline_uid\x18\x02 \x01(\tR\x0bpipelineUid\x12<\n\x17trigger_count_completed\x18\x03 \x01(\x05\x42\x04\xe2\x41\x01\x03R\x15triggerCountCompleted\x12\x38\n\x15trigger_count_errored\x18\x04 \x01(\x05\x42\x04\xe2\x41\x01\x03R\x13triggerCountErrored\x12\x34\n\x13pipeline_release_id\x18\x05 \x01(\tB\x04\xe2\x41\x01\x03R\x11pipelineReleaseId\x12\x36\n\x14pipeline_release_uid\x18\x06 \x01(\tB\x04\xe2\x41\x01\x03R\x12pipelineReleaseUid\"\xed\x03\n\x1aPipelineTriggerChartRecord\x12\x1f\n\x0bpipeline_id\x18\x01 \x01(\tR\npipelineId\x12!\n\x0cpipeline_uid\x18\x02 \x01(\tR\x0bpipelineUid\x12\x39\n\x0ctrigger_mode\x18\x03 \x01(\x0e\x32\x16.core.mgmt.v1beta.ModeR\x0btriggerMode\x12\x36\n\x06status\x18\x04 \x01(\x0e\x32\x18.core.mgmt.v1beta.StatusB\x04\xe2\x41\x01\x03R\x06status\x12\x43\n\x0ctime_buckets\x18\x05 \x03(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\x0btimeBuckets\x12+\n\x0etrigger_counts\x18\x06 \x03(\x05\x42\x04\xe2\x41\x01\x03R\rtriggerCounts\x12\x38\n\x15\x63ompute_time_duration\x18\x07 \x03(\x02\x42\x04\xe2\x41\x01\x03R\x13\x63omputeTimeDuration\x12\x34\n\x13pipeline_release_id\x18\x08 \x01(\tB\x04\xe2\x41\x01\x03R\x11pipelineReleaseId\x12\x36\n\x14pipeline_release_uid\x18\t \x01(\tB\x04\xe2\x41\x01\x03R\x12pipelineReleaseUid\"\xc0\x01\n!ListPipelineTriggerRecordsRequest\x12&\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x00R\x08pageSize\x88\x01\x01\x12(\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01H\x01R\tpageToken\x88\x01\x01\x12!\n\x06\x66ilter\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01H\x02R\x06\x66ilter\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\t\n\x07_filter\"\xce\x01\n\"ListPipelineTriggerRecordsResponse\x12\x61\n\x18pipeline_trigger_records\x18\x01 \x03(\x0b\x32\'.core.mgmt.v1beta.PipelineTriggerRecordR\x16pipelineTriggerRecords\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"\xc5\x01\n&ListPipelineTriggerTableRecordsRequest\x12&\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x00R\x08pageSize\x88\x01\x01\x12(\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01H\x01R\tpageToken\x88\x01\x01\x12!\n\x06\x66ilter\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01H\x02R\x06\x66ilter\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\t\n\x07_filter\"\xe3\x01\n\'ListPipelineTriggerTableRecordsResponse\x12q\n\x1epipeline_trigger_table_records\x18\x01 \x03(\x0b\x32,.core.mgmt.v1beta.PipelineTriggerTableRecordR\x1bpipelineTriggerTableRecords\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"\x85\x01\n&ListPipelineTriggerChartRecordsRequest\x12-\n\x12\x61ggregation_window\x18\x01 \x01(\x05R\x11\x61ggregationWindow\x12!\n\x06\x66ilter\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01H\x00R\x06\x66ilter\x88\x01\x01\x42\t\n\x07_filter\"\x9c\x01\n\'ListPipelineTriggerChartRecordsResponse\x12q\n\x1epipeline_trigger_chart_records\x18\x01 \x03(\x0b\x32,.core.mgmt.v1beta.PipelineTriggerChartRecordR\x1bpipelineTriggerChartRecords\"\xf1\x03\n\x16\x43onnectorExecuteRecord\x12=\n\x0c\x65xecute_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0b\x65xecuteTime\x12\x30\n\x14\x63onnector_execute_id\x18\x02 \x01(\tR\x12\x63onnectorExecuteId\x12!\n\x0c\x63onnector_id\x18\x03 \x01(\tR\x0b\x63onnectorId\x12#\n\rconnector_uid\x18\x04 \x01(\tR\x0c\x63onnectorUid\x12\x38\n\x18\x63onnector_definition_uid\x18\x05 \x01(\tR\x16\x63onnectorDefinitionUid\x12\x1f\n\x0bpipeline_id\x18\x06 \x01(\tR\npipelineId\x12!\n\x0cpipeline_uid\x18\x07 \x01(\tR\x0bpipelineUid\x12.\n\x13pipeline_trigger_id\x18\x08 \x01(\tR\x11pipelineTriggerId\x12\x38\n\x15\x63ompute_time_duration\x18\t \x01(\x02\x42\x04\xe2\x41\x01\x03R\x13\x63omputeTimeDuration\x12\x36\n\x06status\x18\n \x01(\x0e\x32\x18.core.mgmt.v1beta.StatusB\x04\xe2\x41\x01\x03R\x06status\"\xdd\x01\n\x1b\x43onnectorExecuteTableRecord\x12!\n\x0c\x63onnector_id\x18\x01 \x01(\tR\x0b\x63onnectorId\x12#\n\rconnector_uid\x18\x02 \x01(\tR\x0c\x63onnectorUid\x12<\n\x17\x65xecute_count_completed\x18\x03 \x01(\x05\x42\x04\xe2\x41\x01\x03R\x15\x65xecuteCountCompleted\x12\x38\n\x15\x65xecute_count_errored\x18\x04 \x01(\x05\x42\x04\xe2\x41\x01\x03R\x13\x65xecuteCountErrored\"\xc9\x02\n\x1b\x43onnectorExecuteChartRecord\x12!\n\x0c\x63onnector_id\x18\x01 \x01(\tR\x0b\x63onnectorId\x12#\n\rconnector_uid\x18\x02 \x01(\tR\x0c\x63onnectorUid\x12\x36\n\x06status\x18\x03 \x01(\x0e\x32\x18.core.mgmt.v1beta.StatusB\x04\xe2\x41\x01\x03R\x06status\x12\x43\n\x0ctime_buckets\x18\x04 \x03(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\x0btimeBuckets\x12+\n\x0e\x65xecute_counts\x18\x05 \x03(\x05\x42\x04\xe2\x41\x01\x03R\rexecuteCounts\x12\x38\n\x15\x63ompute_time_duration\x18\x06 \x03(\x02\x42\x04\xe2\x41\x01\x03R\x13\x63omputeTimeDuration\"\xc1\x01\n\"ListConnectorExecuteRecordsRequest\x12&\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x00R\x08pageSize\x88\x01\x01\x12(\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01H\x01R\tpageToken\x88\x01\x01\x12!\n\x06\x66ilter\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01H\x02R\x06\x66ilter\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\t\n\x07_filter\"\xd2\x01\n#ListConnectorExecuteRecordsResponse\x12\x64\n\x19\x63onnector_execute_records\x18\x01 \x03(\x0b\x32(.core.mgmt.v1beta.ConnectorExecuteRecordR\x17\x63onnectorExecuteRecords\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"\xc6\x01\n\'ListConnectorExecuteTableRecordsRequest\x12&\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x00R\x08pageSize\x88\x01\x01\x12(\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01H\x01R\tpageToken\x88\x01\x01\x12!\n\x06\x66ilter\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01H\x02R\x06\x66ilter\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\t\n\x07_filter\"\xe7\x01\n(ListConnectorExecuteTableRecordsResponse\x12t\n\x1f\x63onnector_execute_table_records\x18\x01 \x03(\x0b\x32-.core.mgmt.v1beta.ConnectorExecuteTableRecordR\x1c\x63onnectorExecuteTableRecords\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"\x86\x01\n\'ListConnectorExecuteChartRecordsRequest\x12-\n\x12\x61ggregation_window\x18\x01 \x01(\x05R\x11\x61ggregationWindow\x12!\n\x06\x66ilter\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01H\x00R\x06\x66ilter\x88\x01\x01\x42\t\n\x07_filter\"\xa0\x01\n(ListConnectorExecuteChartRecordsResponse\x12t\n\x1f\x63onnector_execute_chart_records\x18\x01 \x03(\x0b\x32-.core.mgmt.v1beta.ConnectorExecuteChartRecordR\x1c\x63onnectorExecuteChartRecords*;\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\r\n\tMODE_SYNC\x10\x01\x12\x0e\n\nMODE_ASYNC\x10\x02*J\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x14\n\x10STATUS_COMPLETED\x10\x01\x12\x12\n\x0eSTATUS_ERRORED\x10\x02\x42\xc4\x01\n\x14\x63om.core.mgmt.v1betaB\x0bMetricProtoP\x01Z=github.com/instill-ai/protogen-go/core/mgmt/v1beta;mgmtv1beta\xa2\x02\x03\x43MX\xaa\x02\x10\x43ore.Mgmt.V1beta\xca\x02\x10\x43ore\\Mgmt\\V1beta\xe2\x02\x1c\x43ore\\Mgmt\\V1beta\\GPBMetadata\xea\x02\x12\x43ore::Mgmt::V1betab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'core.mgmt.v1beta.metric_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024com.core.mgmt.v1betaB\013MetricProtoP\001Z=github.com/instill-ai/protogen-go/core/mgmt/v1beta;mgmtv1beta\242\002\003CMX\252\002\020Core.Mgmt.V1beta\312\002\020Core\\Mgmt\\V1beta\342\002\034Core\\Mgmt\\V1beta\\GPBMetadata\352\002\022Core::Mgmt::V1beta'
  _PIPELINETRIGGERRECORD.fields_by_name['compute_time_duration']._options = None
  _PIPELINETRIGGERRECORD.fields_by_name['compute_time_duration']._serialized_options = b'\342A\001\003'
  _PIPELINETRIGGERRECORD.fields_by_name['status']._options = None
  _PIPELINETRIGGERRECORD.fields_by_name['status']._serialized_options = b'\342A\001\003'
  _PIPELINETRIGGERRECORD.fields_by_name['pipeline_release_id']._options = None
  _PIPELINETRIGGERRECORD.fields_by_name['pipeline_release_id']._serialized_options = b'\342A\001\003'
  _PIPELINETRIGGERRECORD.fields_by_name['pipeline_release_uid']._options = None
  _PIPELINETRIGGERRECORD.fields_by_name['pipeline_release_uid']._serialized_options = b'\342A\001\003'
  _PIPELINETRIGGERTABLERECORD.fields_by_name['trigger_count_completed']._options = None
  _PIPELINETRIGGERTABLERECORD.fields_by_name['trigger_count_completed']._serialized_options = b'\342A\001\003'
  _PIPELINETRIGGERTABLERECORD.fields_by_name['trigger_count_errored']._options = None
  _PIPELINETRIGGERTABLERECORD.fields_by_name['trigger_count_errored']._serialized_options = b'\342A\001\003'
  _PIPELINETRIGGERTABLERECORD.fields_by_name['pipeline_release_id']._options = None
  _PIPELINETRIGGERTABLERECORD.fields_by_name['pipeline_release_id']._serialized_options = b'\342A\001\003'
  _PIPELINETRIGGERTABLERECORD.fields_by_name['pipeline_release_uid']._options = None
  _PIPELINETRIGGERTABLERECORD.fields_by_name['pipeline_release_uid']._serialized_options = b'\342A\001\003'
  _PIPELINETRIGGERCHARTRECORD.fields_by_name['status']._options = None
  _PIPELINETRIGGERCHARTRECORD.fields_by_name['status']._serialized_options = b'\342A\001\003'
  _PIPELINETRIGGERCHARTRECORD.fields_by_name['time_buckets']._options = None
  _PIPELINETRIGGERCHARTRECORD.fields_by_name['time_buckets']._serialized_options = b'\342A\001\003'
  _PIPELINETRIGGERCHARTRECORD.fields_by_name['trigger_counts']._options = None
  _PIPELINETRIGGERCHARTRECORD.fields_by_name['trigger_counts']._serialized_options = b'\342A\001\003'
  _PIPELINETRIGGERCHARTRECORD.fields_by_name['compute_time_duration']._options = None
  _PIPELINETRIGGERCHARTRECORD.fields_by_name['compute_time_duration']._serialized_options = b'\342A\001\003'
  _PIPELINETRIGGERCHARTRECORD.fields_by_name['pipeline_release_id']._options = None
  _PIPELINETRIGGERCHARTRECORD.fields_by_name['pipeline_release_id']._serialized_options = b'\342A\001\003'
  _PIPELINETRIGGERCHARTRECORD.fields_by_name['pipeline_release_uid']._options = None
  _PIPELINETRIGGERCHARTRECORD.fields_by_name['pipeline_release_uid']._serialized_options = b'\342A\001\003'
  _LISTPIPELINETRIGGERRECORDSREQUEST.fields_by_name['page_size']._options = None
  _LISTPIPELINETRIGGERRECORDSREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTPIPELINETRIGGERRECORDSREQUEST.fields_by_name['page_token']._options = None
  _LISTPIPELINETRIGGERRECORDSREQUEST.fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _LISTPIPELINETRIGGERRECORDSREQUEST.fields_by_name['filter']._options = None
  _LISTPIPELINETRIGGERRECORDSREQUEST.fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _LISTPIPELINETRIGGERTABLERECORDSREQUEST.fields_by_name['page_size']._options = None
  _LISTPIPELINETRIGGERTABLERECORDSREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTPIPELINETRIGGERTABLERECORDSREQUEST.fields_by_name['page_token']._options = None
  _LISTPIPELINETRIGGERTABLERECORDSREQUEST.fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _LISTPIPELINETRIGGERTABLERECORDSREQUEST.fields_by_name['filter']._options = None
  _LISTPIPELINETRIGGERTABLERECORDSREQUEST.fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _LISTPIPELINETRIGGERCHARTRECORDSREQUEST.fields_by_name['filter']._options = None
  _LISTPIPELINETRIGGERCHARTRECORDSREQUEST.fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _CONNECTOREXECUTERECORD.fields_by_name['compute_time_duration']._options = None
  _CONNECTOREXECUTERECORD.fields_by_name['compute_time_duration']._serialized_options = b'\342A\001\003'
  _CONNECTOREXECUTERECORD.fields_by_name['status']._options = None
  _CONNECTOREXECUTERECORD.fields_by_name['status']._serialized_options = b'\342A\001\003'
  _CONNECTOREXECUTETABLERECORD.fields_by_name['execute_count_completed']._options = None
  _CONNECTOREXECUTETABLERECORD.fields_by_name['execute_count_completed']._serialized_options = b'\342A\001\003'
  _CONNECTOREXECUTETABLERECORD.fields_by_name['execute_count_errored']._options = None
  _CONNECTOREXECUTETABLERECORD.fields_by_name['execute_count_errored']._serialized_options = b'\342A\001\003'
  _CONNECTOREXECUTECHARTRECORD.fields_by_name['status']._options = None
  _CONNECTOREXECUTECHARTRECORD.fields_by_name['status']._serialized_options = b'\342A\001\003'
  _CONNECTOREXECUTECHARTRECORD.fields_by_name['time_buckets']._options = None
  _CONNECTOREXECUTECHARTRECORD.fields_by_name['time_buckets']._serialized_options = b'\342A\001\003'
  _CONNECTOREXECUTECHARTRECORD.fields_by_name['execute_counts']._options = None
  _CONNECTOREXECUTECHARTRECORD.fields_by_name['execute_counts']._serialized_options = b'\342A\001\003'
  _CONNECTOREXECUTECHARTRECORD.fields_by_name['compute_time_duration']._options = None
  _CONNECTOREXECUTECHARTRECORD.fields_by_name['compute_time_duration']._serialized_options = b'\342A\001\003'
  _LISTCONNECTOREXECUTERECORDSREQUEST.fields_by_name['page_size']._options = None
  _LISTCONNECTOREXECUTERECORDSREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTCONNECTOREXECUTERECORDSREQUEST.fields_by_name['page_token']._options = None
  _LISTCONNECTOREXECUTERECORDSREQUEST.fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _LISTCONNECTOREXECUTERECORDSREQUEST.fields_by_name['filter']._options = None
  _LISTCONNECTOREXECUTERECORDSREQUEST.fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _LISTCONNECTOREXECUTETABLERECORDSREQUEST.fields_by_name['page_size']._options = None
  _LISTCONNECTOREXECUTETABLERECORDSREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTCONNECTOREXECUTETABLERECORDSREQUEST.fields_by_name['page_token']._options = None
  _LISTCONNECTOREXECUTETABLERECORDSREQUEST.fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _LISTCONNECTOREXECUTETABLERECORDSREQUEST.fields_by_name['filter']._options = None
  _LISTCONNECTOREXECUTETABLERECORDSREQUEST.fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _LISTCONNECTOREXECUTECHARTRECORDSREQUEST.fields_by_name['filter']._options = None
  _LISTCONNECTOREXECUTECHARTRECORDSREQUEST.fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_MODE']._serialized_start=4759
  _globals['_MODE']._serialized_end=4818
  _globals['_STATUS']._serialized_start=4820
  _globals['_STATUS']._serialized_end=4894
  _globals['_PIPELINETRIGGERRECORD']._serialized_start=118
  _globals['_PIPELINETRIGGERRECORD']._serialized_end=603
  _globals['_PIPELINETRIGGERTABLERECORD']._serialized_start=606
  _globals['_PIPELINETRIGGERTABLERECORD']._serialized_end=932
  _globals['_PIPELINETRIGGERCHARTRECORD']._serialized_start=935
  _globals['_PIPELINETRIGGERCHARTRECORD']._serialized_end=1428
  _globals['_LISTPIPELINETRIGGERRECORDSREQUEST']._serialized_start=1431
  _globals['_LISTPIPELINETRIGGERRECORDSREQUEST']._serialized_end=1623
  _globals['_LISTPIPELINETRIGGERRECORDSRESPONSE']._serialized_start=1626
  _globals['_LISTPIPELINETRIGGERRECORDSRESPONSE']._serialized_end=1832
  _globals['_LISTPIPELINETRIGGERTABLERECORDSREQUEST']._serialized_start=1835
  _globals['_LISTPIPELINETRIGGERTABLERECORDSREQUEST']._serialized_end=2032
  _globals['_LISTPIPELINETRIGGERTABLERECORDSRESPONSE']._serialized_start=2035
  _globals['_LISTPIPELINETRIGGERTABLERECORDSRESPONSE']._serialized_end=2262
  _globals['_LISTPIPELINETRIGGERCHARTRECORDSREQUEST']._serialized_start=2265
  _globals['_LISTPIPELINETRIGGERCHARTRECORDSREQUEST']._serialized_end=2398
  _globals['_LISTPIPELINETRIGGERCHARTRECORDSRESPONSE']._serialized_start=2401
  _globals['_LISTPIPELINETRIGGERCHARTRECORDSRESPONSE']._serialized_end=2557
  _globals['_CONNECTOREXECUTERECORD']._serialized_start=2560
  _globals['_CONNECTOREXECUTERECORD']._serialized_end=3057
  _globals['_CONNECTOREXECUTETABLERECORD']._serialized_start=3060
  _globals['_CONNECTOREXECUTETABLERECORD']._serialized_end=3281
  _globals['_CONNECTOREXECUTECHARTRECORD']._serialized_start=3284
  _globals['_CONNECTOREXECUTECHARTRECORD']._serialized_end=3613
  _globals['_LISTCONNECTOREXECUTERECORDSREQUEST']._serialized_start=3616
  _globals['_LISTCONNECTOREXECUTERECORDSREQUEST']._serialized_end=3809
  _globals['_LISTCONNECTOREXECUTERECORDSRESPONSE']._serialized_start=3812
  _globals['_LISTCONNECTOREXECUTERECORDSRESPONSE']._serialized_end=4022
  _globals['_LISTCONNECTOREXECUTETABLERECORDSREQUEST']._serialized_start=4025
  _globals['_LISTCONNECTOREXECUTETABLERECORDSREQUEST']._serialized_end=4223
  _globals['_LISTCONNECTOREXECUTETABLERECORDSRESPONSE']._serialized_start=4226
  _globals['_LISTCONNECTOREXECUTETABLERECORDSRESPONSE']._serialized_end=4457
  _globals['_LISTCONNECTOREXECUTECHARTRECORDSREQUEST']._serialized_start=4460
  _globals['_LISTCONNECTOREXECUTECHARTRECORDSREQUEST']._serialized_end=4594
  _globals['_LISTCONNECTOREXECUTECHARTRECORDSRESPONSE']._serialized_start=4597
  _globals['_LISTCONNECTOREXECUTECHARTRECORDSRESPONSE']._serialized_end=4757
# @@protoc_insertion_point(module_scope)



# generated by datamodel-codegen:
#   filename:  restapi_task_get_input.json

from __future__ import annotations

from dataclasses import dataclass
from typing import Optional


@dataclass
class InputWithoutBody:
    endpoint_url: str
    output_body_schema: Optional[str] = None



# generated by datamodel-codegen:
#   filename:  website_task_scrape_website_input.json

from __future__ import annotations

from dataclasses import dataclass
from typing import List, Optional


@dataclass
class Input:
    max_k: int
    target_url: str
    allowed_domains: Optional[List[str]] = None
    include_link_html: Optional[bool] = False
    include_link_text: Optional[bool] = False



# generated by datamodel-codegen:
#   filename:  text_task_split_by_token_input.json

from __future__ import annotations

from dataclasses import dataclass
from enum import Enum
from typing import Optional


class Model(Enum):
    gpt_4 = 'gpt-4'
    gpt_3_5_turbo = 'gpt-3.5-turbo'
    text_davinci_003 = 'text-davinci-003'
    text_davinci_002 = 'text-davinci-002'
    text_davinci_001 = 'text-davinci-001'
    text_curie_001 = 'text-curie-001'
    text_babbage_001 = 'text-babbage-001'
    text_ada_001 = 'text-ada-001'
    davinci = 'davinci'
    curie = 'curie'
    babbage = 'babbage'
    ada = 'ada'
    code_davinci_002 = 'code-davinci-002'
    code_davinci_001 = 'code-davinci-001'
    code_cushman_002 = 'code-cushman-002'
    code_cushman_001 = 'code-cushman-001'
    davinci_codex = 'davinci-codex'
    cushman_codex = 'cushman-codex'
    text_davinci_edit_001 = 'text-davinci-edit-001'
    code_davinci_edit_001 = 'code-davinci-edit-001'
    text_embedding_ada_002 = 'text-embedding-ada-002'
    text_similarity_davinci_001 = 'text-similarity-davinci-001'
    text_similarity_curie_001 = 'text-similarity-curie-001'
    text_similarity_babbage_001 = 'text-similarity-babbage-001'
    text_similarity_ada_001 = 'text-similarity-ada-001'
    text_search_davinci_doc_001 = 'text-search-davinci-doc-001'
    text_search_curie_doc_001 = 'text-search-curie-doc-001'
    text_search_babbage_doc_001 = 'text-search-babbage-doc-001'
    text_search_ada_doc_001 = 'text-search-ada-doc-001'
    code_search_babbage_code_001 = 'code-search-babbage-code-001'
    code_search_ada_code_001 = 'code-search-ada-code-001'
    gpt2 = 'gpt2'


@dataclass
class Input:
    model: Model
    text: str
    chunk_token_size: Optional[int] = 500



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vdp/pipeline/v1beta/pipeline_private_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2
from vdp.pipeline.v1beta import connector_pb2 as vdp_dot_pipeline_dot_v1beta_dot_connector__pb2
from vdp.pipeline.v1beta import connector_definition_pb2 as vdp_dot_pipeline_dot_v1beta_dot_connector__definition__pb2
from vdp.pipeline.v1beta import operator_definition_pb2 as vdp_dot_pipeline_dot_v1beta_dot_operator__definition__pb2
from vdp.pipeline.v1beta import pipeline_pb2 as vdp_dot_pipeline_dot_v1beta_dot_pipeline__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2vdp/pipeline/v1beta/pipeline_private_service.proto\x12\x13vdp.pipeline.v1beta\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1bgoogle/api/visibility.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\x1a#vdp/pipeline/v1beta/connector.proto\x1a.vdp/pipeline/v1beta/connector_definition.proto\x1a-vdp/pipeline/v1beta/operator_definition.proto\x1a\"vdp/pipeline/v1beta/pipeline.proto2\xc2\x0c\n\x16PipelinePrivateService\x12\x96\x01\n\x12ListPipelinesAdmin\x12..vdp.pipeline.v1beta.ListPipelinesAdminRequest\x1a/.vdp.pipeline.v1beta.ListPipelinesAdminResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/v1beta/admin/pipelines\x12\xba\x01\n\x13LookUpPipelineAdmin\x12/.vdp.pipeline.v1beta.LookUpPipelineAdminRequest\x1a\x30.vdp.pipeline.v1beta.LookUpPipelineAdminResponse\"@\xda\x41\tpermalink\x82\xd3\xe4\x93\x02.\x12,/v1beta/admin/{permalink=pipelines/*}/lookUp\x12\xe3\x01\n\x1dLookUpOperatorDefinitionAdmin\x12\x39.vdp.pipeline.v1beta.LookUpOperatorDefinitionAdminRequest\x1a:.vdp.pipeline.v1beta.LookUpOperatorDefinitionAdminResponse\"K\xda\x41\tpermalink\x82\xd3\xe4\x93\x02\x39\x12\x37/v1beta/admin/{permalink=operator-definitions/*}/lookUp\x12\xaa\x01\n\x19ListPipelineReleasesAdmin\x12\x35.vdp.pipeline.v1beta.ListPipelineReleasesAdminRequest\x1a\x36.vdp.pipeline.v1beta.ListPipelineReleasesAdminResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/v1beta/admin/releases\x12\xe7\x01\n\x1eLookUpConnectorDefinitionAdmin\x12:.vdp.pipeline.v1beta.LookUpConnectorDefinitionAdminRequest\x1a;.vdp.pipeline.v1beta.LookUpConnectorDefinitionAdminResponse\"L\xda\x41\tpermalink\x82\xd3\xe4\x93\x02:\x12\x38/v1beta/admin/{permalink=connector-definitions/*}/lookUp\x12\x9a\x01\n\x13ListConnectorsAdmin\x12/.vdp.pipeline.v1beta.ListConnectorsAdminRequest\x1a\x30.vdp.pipeline.v1beta.ListConnectorsAdminResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/v1beta/admin/connectors\x12\xbe\x01\n\x14LookUpConnectorAdmin\x12\x30.vdp.pipeline.v1beta.LookUpConnectorAdminRequest\x1a\x31.vdp.pipeline.v1beta.LookUpConnectorAdminResponse\"A\xda\x41\tpermalink\x82\xd3\xe4\x93\x02/\x12-/v1beta/admin/{permalink=connectors/*}/lookUp\x12\xab\x01\n\x0e\x43heckConnector\x12*.vdp.pipeline.v1beta.CheckConnectorRequest\x1a+.vdp.pipeline.v1beta.CheckConnectorResponse\"@\xda\x41\tpermalink\x82\xd3\xe4\x93\x02.\x12,/v1beta/admin/{permalink=connectors/*}/check\x1aI\x92\x41\x36\x12\x34Private methods to interact with Pipeline resources.\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNALB\xea\x01\n\x17\x63om.vdp.pipeline.v1betaB\x1bPipelinePrivateServiceProtoP\x01ZDgithub.com/instill-ai/protogen-go/vdp/pipeline/v1beta;pipelinev1beta\xa2\x02\x03VPX\xaa\x02\x13Vdp.Pipeline.V1beta\xca\x02\x13Vdp\\Pipeline\\V1beta\xe2\x02\x1fVdp\\Pipeline\\V1beta\\GPBMetadata\xea\x02\x15Vdp::Pipeline::V1betab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vdp.pipeline.v1beta.pipeline_private_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.vdp.pipeline.v1betaB\033PipelinePrivateServiceProtoP\001ZDgithub.com/instill-ai/protogen-go/vdp/pipeline/v1beta;pipelinev1beta\242\002\003VPX\252\002\023Vdp.Pipeline.V1beta\312\002\023Vdp\\Pipeline\\V1beta\342\002\037Vdp\\Pipeline\\V1beta\\GPBMetadata\352\002\025Vdp::Pipeline::V1beta'
  _PIPELINEPRIVATESERVICE._options = None
  _PIPELINEPRIVATESERVICE._serialized_options = b'\222A6\0224Private methods to interact with Pipeline resources.\372\322\344\223\002\n\022\010INTERNAL'
  _PIPELINEPRIVATESERVICE.methods_by_name['ListPipelinesAdmin']._options = None
  _PIPELINEPRIVATESERVICE.methods_by_name['ListPipelinesAdmin']._serialized_options = b'\202\323\344\223\002\031\022\027/v1beta/admin/pipelines'
  _PIPELINEPRIVATESERVICE.methods_by_name['LookUpPipelineAdmin']._options = None
  _PIPELINEPRIVATESERVICE.methods_by_name['LookUpPipelineAdmin']._serialized_options = b'\332A\tpermalink\202\323\344\223\002.\022,/v1beta/admin/{permalink=pipelines/*}/lookUp'
  _PIPELINEPRIVATESERVICE.methods_by_name['LookUpOperatorDefinitionAdmin']._options = None
  _PIPELINEPRIVATESERVICE.methods_by_name['LookUpOperatorDefinitionAdmin']._serialized_options = b'\332A\tpermalink\202\323\344\223\0029\0227/v1beta/admin/{permalink=operator-definitions/*}/lookUp'
  _PIPELINEPRIVATESERVICE.methods_by_name['ListPipelineReleasesAdmin']._options = None
  _PIPELINEPRIVATESERVICE.methods_by_name['ListPipelineReleasesAdmin']._serialized_options = b'\202\323\344\223\002\030\022\026/v1beta/admin/releases'
  _PIPELINEPRIVATESERVICE.methods_by_name['LookUpConnectorDefinitionAdmin']._options = None
  _PIPELINEPRIVATESERVICE.methods_by_name['LookUpConnectorDefinitionAdmin']._serialized_options = b'\332A\tpermalink\202\323\344\223\002:\0228/v1beta/admin/{permalink=connector-definitions/*}/lookUp'
  _PIPELINEPRIVATESERVICE.methods_by_name['ListConnectorsAdmin']._options = None
  _PIPELINEPRIVATESERVICE.methods_by_name['ListConnectorsAdmin']._serialized_options = b'\202\323\344\223\002\032\022\030/v1beta/admin/connectors'
  _PIPELINEPRIVATESERVICE.methods_by_name['LookUpConnectorAdmin']._options = None
  _PIPELINEPRIVATESERVICE.methods_by_name['LookUpConnectorAdmin']._serialized_options = b'\332A\tpermalink\202\323\344\223\002/\022-/v1beta/admin/{permalink=connectors/*}/lookUp'
  _PIPELINEPRIVATESERVICE.methods_by_name['CheckConnector']._options = None
  _PIPELINEPRIVATESERVICE.methods_by_name['CheckConnector']._serialized_options = b'\332A\tpermalink\202\323\344\223\002.\022,/v1beta/admin/{permalink=connectors/*}/check'
  _globals['_PIPELINEPRIVATESERVICE']._serialized_start=376
  _globals['_PIPELINEPRIVATESERVICE']._serialized_end=1978
# @@protoc_insertion_point(module_scope)



# generated by datamodel-codegen:
#   filename:  image_task_draw_classification_output.json

from __future__ import annotations

from dataclasses import dataclass


@dataclass
class Output:
    image: str



# generated by datamodel-codegen:
#   filename:  huggingface_task_fill_mask_output.json

from __future__ import annotations

from dataclasses import dataclass
from typing import List, Optional


@dataclass
class Result:
    score: Optional[float] = None
    sequence: Optional[str] = None
    token: Optional[int] = None
    token_str: Optional[str] = None


@dataclass
class Output:
    results: List[Result]



# pylint: disable=no-member,wrong-import-position
from typing import Dict

from google.protobuf import field_mask_pb2

# common
import instill.protogen.common.healthcheck.v1beta.healthcheck_pb2 as healthcheck
import instill.protogen.model.model.v1alpha.model_definition_pb2 as model_definition_interface

# model
import instill.protogen.model.model.v1alpha.model_pb2 as model_interface
import instill.protogen.model.model.v1alpha.model_public_service_pb2_grpc as model_service
from instill.clients.base import Client, RequestFactory
from instill.clients.constant import DEFAULT_INSTANCE
from instill.clients.instance import InstillInstance
from instill.configuration import global_config
from instill.utils.error_handler import grpc_handler


class ModelClient(Client):
    def __init__(self, namespace: str, async_enabled: bool) -> None:
        self.hosts: Dict[str, InstillInstance] = {}
        self.namespace: str = namespace
        if DEFAULT_INSTANCE in global_config.hosts:
            self.instance = DEFAULT_INSTANCE
        elif len(global_config.hosts) == 0:
            self.instance = ""
        else:
            self.instance = list(global_config.hosts.keys())[0]

        if global_config.hosts is not None:
            for instance, config in global_config.hosts.items():
                self.hosts[instance] = InstillInstance(
                    model_service.ModelPublicServiceStub,
                    url=config.url,
                    token=config.token,
                    secure=config.secure,
                    async_enabled=async_enabled,
                )

    @property
    def hosts(self):
        return self._hosts

    @hosts.setter
    def hosts(self, hosts: str):
        self._hosts = hosts

    @property
    def instance(self):
        return self._instance

    @instance.setter
    def instance(self, instance: str):
        self._instance = instance

    @property
    def metadata(self):
        return self._metadata

    @metadata.setter
    def metadata(self, metadata: str):
        self._metadata = metadata

    def liveness(self, async_enabled: bool = False) -> model_interface.LivenessResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.Liveness,
                request=model_interface.LivenessRequest(),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.Liveness,
            request=model_interface.LivenessRequest(),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    def readiness(
        self, async_enabled: bool = False
    ) -> model_interface.ReadinessResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.Readiness,
                request=model_interface.ReadinessRequest(),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.Readiness,
            request=model_interface.ReadinessRequest(),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    def is_serving(self) -> bool:
        try:
            return (
                self.readiness().health_check_response.status
                == healthcheck.HealthCheckResponse.SERVING_STATUS_SERVING
            )
        except Exception:
            return False

    @grpc_handler
    def watch_model(
        self,
        model_name: str,
        async_enabled: bool = False,
    ) -> model_interface.WatchUserModelResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.WatchUserModel,
                request=model_interface.WatchUserModelRequest(
                    name=f"{self.namespace}/models/{model_name}"
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.WatchUserModel,
            request=model_interface.WatchUserModelRequest(
                name=f"{self.namespace}/models/{model_name}"
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def create_model_local(
        self,
        model_name: str,
        model_description: str,
        model_path: str,
    ) -> model_interface.CreateUserModelBinaryFileUploadResponse:
        model = model_interface.Model()
        model.id = model_name
        model.description = model_description
        model.model_definition = "model-definitions/local"

        with open(model_path, "rb") as f:
            data = f.read()
            req = model_interface.CreateUserModelBinaryFileUploadRequest(
                parent=self.namespace, model=model, content=data
            )
        return RequestFactory(
            method=self.hosts[self.instance].client.CreateUserModelBinaryFileUpload,
            request=req,
            metadata=self.hosts[self.instance].metadata,
        ).send_stream()

    @grpc_handler
    def create_model(
        self,
        name: str,
        definition: str,
        configuration: dict,
        async_enabled: bool = False,
    ) -> model_interface.CreateUserModelResponse:
        model = model_interface.Model()
        model.id = name
        model.model_definition = definition
        model.configuration.update(configuration)
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.CreateUserModel,
                request=model_interface.CreateUserModelRequest(
                    model=model, parent=self.namespace
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.CreateUserModel,
            request=model_interface.CreateUserModelRequest(
                model=model, parent=self.namespace
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def deploy_model(
        self,
        model_name: str,
        async_enabled: bool = False,
    ) -> model_interface.DeployUserModelResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.DeployUserModel,
                request=model_interface.DeployUserModelRequest(
                    name=f"{self.namespace}/models/{model_name}"
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.DeployUserModel,
            request=model_interface.DeployUserModelRequest(
                name=f"{self.namespace}/models/{model_name}"
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def undeploy_model(
        self,
        model_name: str,
        async_enabled: bool = False,
    ) -> model_interface.UndeployUserModelResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.UndeployUserModel,
                request=model_interface.UndeployUserModelRequest(
                    name=f"{self.namespace}/models/{model_name}"
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.UndeployUserModel,
            request=model_interface.UndeployUserModelRequest(
                name=f"{self.namespace}/models/{model_name}"
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def trigger_model(
        self,
        model_name: str,
        task_inputs: list,
        async_enabled: bool = False,
    ) -> model_interface.TriggerUserModelResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.TriggerUserModel,
                request=model_interface.TriggerUserModelRequest(
                    name=f"{self.namespace}/models/{model_name}",
                    task_inputs=task_inputs,
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.TriggerUserModel,
            request=model_interface.TriggerUserModelRequest(
                name=f"{self.namespace}/models/{model_name}", task_inputs=task_inputs
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def delete_model(
        self,
        model_name: str,
        async_enabled: bool = False,
    ) -> model_interface.DeleteUserModelResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.DeleteUserModel,
                request=model_interface.DeleteUserModelRequest(
                    name=f"{self.namespace}/models/{model_name}"
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.DeleteUserModel,
            request=model_interface.DeleteUserModelRequest(
                name=f"{self.namespace}/models/{model_name}"
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def get_model(
        self,
        model_name: str,
        async_enabled: bool = False,
    ) -> model_interface.GetUserModelResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.GetUserModel,
                request=model_interface.GetUserModelRequest(
                    name=f"{self.namespace}/models/{model_name}",
                    view=model_definition_interface.VIEW_FULL,
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.GetUserModel,
            request=model_interface.GetUserModelRequest(
                name=f"{self.namespace}/models/{model_name}",
                view=model_definition_interface.VIEW_FULL,
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def update_model(
        self,
        model: model_interface.Model,
        mask: field_mask_pb2.FieldMask,
        async_enabled: bool = False,
    ) -> model_interface.UpdateUserModelResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.UpdateUserModel,
                request=model_interface.UpdateUserModelRequest(
                    model=model,
                    update_mask=mask,
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.UpdateUserModel,
            request=model_interface.UpdateUserModelRequest(
                model=model,
                update_mask=mask,
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def lookup_model(
        self,
        model_uid: str,
        async_enabled: bool = False,
    ) -> model_interface.LookUpModelResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.LookUpModel,
                request=model_interface.LookUpModelRequest(
                    permalink=f"models/{model_uid}"
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.LookUpModel,
            request=model_interface.LookUpModelRequest(permalink=f"models/{model_uid}"),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def get_model_card(
        self,
        model_name: str,
        async_enabled: bool = False,
    ) -> model_interface.GetUserModelCardResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.GetUserModelCard,
                request=model_interface.GetUserModelCardRequest(
                    name=f"{self.namespace}/models/{model_name}"
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.GetUserModelCard,
            request=model_interface.GetUserModelCardRequest(
                name=f"{self.namespace}/models/{model_name}"
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def list_models(
        self,
        next_page_token: str = "",
        total_size: int = 100,
        show_deleted: bool = False,
        public=False,
        async_enabled: bool = False,
    ) -> model_interface.ListUserModelsResponse:
        if async_enabled:
            if public:
                method = self.hosts[self.instance].async_client.ListModels
                return RequestFactory(
                    method=method,
                    request=model_interface.ListModelsRequest(
                        page_size=total_size,
                        page_token=next_page_token,
                        show_deleted=show_deleted,
                        view=model_definition_interface.VIEW_FULL,
                    ),
                    metadata=self.hosts[self.instance].metadata,
                ).send_async()
            method = self.hosts[self.instance].async_client.ListUserModels
            return RequestFactory(
                method=method,
                request=model_interface.ListUserModelsRequest(
                    parent=self.namespace,
                    page_size=total_size,
                    page_token=next_page_token,
                    show_deleted=show_deleted,
                    view=model_definition_interface.VIEW_FULL,
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()
        if public:
            method = self.hosts[self.instance].client.ListModels
            return RequestFactory(
                method=method,
                request=model_interface.ListModelsRequest(
                    page_size=total_size,
                    page_token=next_page_token,
                    show_deleted=show_deleted,
                    view=model_definition_interface.VIEW_FULL,
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_sync()
        method = self.hosts[self.instance].client.ListUserModels
        return RequestFactory(
            method=method,
            request=model_interface.ListUserModelsRequest(
                parent=self.namespace,
                page_size=total_size,
                page_token=next_page_token,
                show_deleted=show_deleted,
                view=model_definition_interface.VIEW_FULL,
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def get_operation(
        self,
        name: str,
        async_enabled: bool = False,
    ) -> model_interface.GetModelOperationResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.GetModelOperation,
                request=model_interface.GetModelOperationRequest(
                    name=name,
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.GetModelOperation,
            request=model_interface.GetModelOperationRequest(
                name=name,
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()



# generated by datamodel-codegen:
#   filename:  huggingface_task_table_question_answering_output.json

from __future__ import annotations

from dataclasses import dataclass
from typing import List, Optional


@dataclass
class Output:
    answer: str
    aggregator: Optional[str] = None
    cells: Optional[List[str]] = None
    coordinates: Optional[List[List[int]]] = None



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: core/mgmt/v1beta/mgmt_public_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from core.mgmt.v1beta import metric_pb2 as core_dot_mgmt_dot_v1beta_dot_metric__pb2
from core.mgmt.v1beta import mgmt_pb2 as core_dot_mgmt_dot_v1beta_dot_mgmt__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*core/mgmt/v1beta/mgmt_public_service.proto\x12\x10\x63ore.mgmt.v1beta\x1a\x1d\x63ore/mgmt/v1beta/metric.proto\x1a\x1b\x63ore/mgmt/v1beta/mgmt.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1bgoogle/api/visibility.proto\x1a.protoc-gen-openapiv2/options/annotations.proto2\xe0\x35\n\x11MgmtPublicService\x12\xca\x01\n\x1c\x44\x65leteOrganizationMembership\x12\x35.core.mgmt.v1beta.DeleteOrganizationMembershipRequest\x1a\x36.core.mgmt.v1beta.DeleteOrganizationMembershipResponse\";\xda\x41\x04name\x82\xd3\xe4\x93\x02.*,/v1beta/{name=organizations/*/memberships/*}\x12\x94\x01\n\x08Liveness\x12!.core.mgmt.v1beta.LivenessRequest\x1a\".core.mgmt.v1beta.LivenessResponse\"A\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02+\x12\x12/v1beta/__livenessZ\x15\x12\x13/v1beta/health/mgmt\x12\x97\x01\n\tReadiness\x12\".core.mgmt.v1beta.ReadinessRequest\x1a#.core.mgmt.v1beta.ReadinessResponse\"A\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02+\x12\x13/v1beta/__readinessZ\x14\x12\x12/v1beta/ready/mgmt\x12\xa3\x01\n\x0e\x43heckNamespace\x12\'.core.mgmt.v1beta.CheckNamespaceRequest\x1a(.core.mgmt.v1beta.CheckNamespaceResponse\">\xda\x41\tnamespace\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x1c\"\x17/v1beta/check-namespace:\x01*\x12\x9e\x01\n\x14GetAuthenticatedUser\x12-.core.mgmt.v1beta.GetAuthenticatedUserRequest\x1a..core.mgmt.v1beta.GetAuthenticatedUserResponse\"\'\xda\x41\x10user,update_mask\x82\xd3\xe4\x93\x02\x0e\x12\x0c/v1beta/user\x12\xaa\x01\n\x16PatchAuthenticatedUser\x12/.core.mgmt.v1beta.PatchAuthenticatedUserRequest\x1a\x30.core.mgmt.v1beta.PatchAuthenticatedUserResponse\"-\xda\x41\x10user,update_mask\x82\xd3\xe4\x93\x02\x14\x32\x0c/v1beta/user:\x04user\x12k\n\tListUsers\x12\".core.mgmt.v1beta.ListUsersRequest\x1a#.core.mgmt.v1beta.ListUsersResponse\"\x15\x82\xd3\xe4\x93\x02\x0f\x12\r/v1beta/users\x12\x85\x01\n\x07GetUser\x12 .core.mgmt.v1beta.GetUserRequest\x1a!.core.mgmt.v1beta.GetUserResponse\"5\xda\x41\x04name\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x18\x12\x16/v1beta/{name=users/*}\x12\xb9\x01\n\x13ListUserMemberships\x12,.core.mgmt.v1beta.ListUserMembershipsRequest\x1a-.core.mgmt.v1beta.ListUserMembershipsResponse\"E\xda\x41\x06parent\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02&\x12$/v1beta/{parent=users/*}/memberships\x12\xb1\x01\n\x11GetUserMembership\x12*.core.mgmt.v1beta.GetUserMembershipRequest\x1a+.core.mgmt.v1beta.GetUserMembershipResponse\"C\xda\x41\x04name\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02&\x12$/v1beta/{name=users/*/memberships/*}\x12\xe3\x01\n\x14UpdateUserMembership\x12-.core.mgmt.v1beta.UpdateUserMembershipRequest\x1a..core.mgmt.v1beta.UpdateUserMembershipResponse\"l\xda\x41\x16membership,update_mask\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02=\x1a//v1beta/{membership.name=users/*/memberships/*}:\nmembership\x12\xaa\x01\n\x14\x44\x65leteUserMembership\x12-.core.mgmt.v1beta.DeleteUserMembershipRequest\x1a..core.mgmt.v1beta.DeleteUserMembershipResponse\"3\xda\x41\x04name\x82\xd3\xe4\x93\x02&*$/v1beta/{name=users/*/memberships/*}\x12\x9b\x01\n\x11ListOrganizations\x12*.core.mgmt.v1beta.ListOrganizationsRequest\x1a+.core.mgmt.v1beta.ListOrganizationsResponse\"-\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x17\x12\x15/v1beta/organizations\x12\xbb\x01\n\x12\x43reateOrganization\x12+.core.mgmt.v1beta.CreateOrganizationRequest\x1a,.core.mgmt.v1beta.CreateOrganizationResponse\"J\xda\x41\x0corganization\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02%\"\x15/v1beta/organizations:\x0corganization\x12\xa5\x01\n\x0fGetOrganization\x12(.core.mgmt.v1beta.GetOrganizationRequest\x1a).core.mgmt.v1beta.GetOrganizationResponse\"=\xda\x41\x04name\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02 \x12\x1e/v1beta/{name=organizations/*}\x12\xdd\x01\n\x12UpdateOrganization\x12+.core.mgmt.v1beta.UpdateOrganizationRequest\x1a,.core.mgmt.v1beta.UpdateOrganizationResponse\"l\xda\x41\x18organization,update_mask\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02;2+/v1beta/{organization.name=organizations/*}:\x0corganization\x12\xae\x01\n\x12\x44\x65leteOrganization\x12+.core.mgmt.v1beta.DeleteOrganizationRequest\x1a,.core.mgmt.v1beta.DeleteOrganizationResponse\"=\xda\x41\x04name\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02 *\x1e/v1beta/{name=organizations/*}\x12\xd9\x01\n\x1bListOrganizationMemberships\x12\x34.core.mgmt.v1beta.ListOrganizationMembershipsRequest\x1a\x35.core.mgmt.v1beta.ListOrganizationMembershipsResponse\"M\xda\x41\x06parent\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02.\x12,/v1beta/{parent=organizations/*}/memberships\x12\xd1\x01\n\x19GetOrganizationMembership\x12\x32.core.mgmt.v1beta.GetOrganizationMembershipRequest\x1a\x33.core.mgmt.v1beta.GetOrganizationMembershipResponse\"K\xda\x41\x04name\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02.\x12,/v1beta/{name=organizations/*/memberships/*}\x12\x83\x02\n\x1cUpdateOrganizationMembership\x12\x35.core.mgmt.v1beta.UpdateOrganizationMembershipRequest\x1a\x36.core.mgmt.v1beta.UpdateOrganizationMembershipResponse\"t\xda\x41\x16membership,update_mask\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x45\x1a\x37/v1beta/{membership.name=organizations/*/memberships/*}:\nmembership\x12\xcc\x01\n GetAuthenticatedUserSubscription\x12\x39.core.mgmt.v1beta.GetAuthenticatedUserSubscriptionRequest\x1a:.core.mgmt.v1beta.GetAuthenticatedUserSubscriptionResponse\"1\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1beta/user/subscription\x12\xda\x01\n\x1bGetOrganizationSubscription\x12\x34.core.mgmt.v1beta.GetOrganizationSubscriptionRequest\x1a\x35.core.mgmt.v1beta.GetOrganizationSubscriptionResponse\"N\xda\x41\x06parent\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02/\x12-/v1beta/{parent=organizations/*}/subscription\x12\x91\x01\n\x0b\x43reateToken\x12$.core.mgmt.v1beta.CreateTokenRequest\x1a%.core.mgmt.v1beta.CreateTokenResponse\"5\xda\x41\x05token\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x17\"\x0e/v1beta/tokens:\x05token\x12\x7f\n\nListTokens\x12#.core.mgmt.v1beta.ListTokensRequest\x1a$.core.mgmt.v1beta.ListTokensResponse\"&\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x10\x12\x0e/v1beta/tokens\x12\x89\x01\n\x08GetToken\x12!.core.mgmt.v1beta.GetTokenRequest\x1a\".core.mgmt.v1beta.GetTokenResponse\"6\xda\x41\x04name\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x19\x12\x17/v1beta/{name=tokens/*}\x12\x92\x01\n\x0b\x44\x65leteToken\x12$.core.mgmt.v1beta.DeleteTokenRequest\x1a%.core.mgmt.v1beta.DeleteTokenResponse\"6\xda\x41\x04name\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x19*\x17/v1beta/{name=tokens/*}\x12\x90\x01\n\rValidateToken\x12&.core.mgmt.v1beta.ValidateTokenRequest\x1a\'.core.mgmt.v1beta.ValidateTokenResponse\".\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x18\"\x16/v1beta/validate_token\x12\xc6\x01\n\x1aListPipelineTriggerRecords\x12\x33.core.mgmt.v1beta.ListPipelineTriggerRecordsRequest\x1a\x34.core.mgmt.v1beta.ListPipelineTriggerRecordsResponse\"=\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\'\x12%/v1beta/metrics/vdp/pipeline/triggers\x12\xd3\x01\n\x1fListPipelineTriggerTableRecords\x12\x38.core.mgmt.v1beta.ListPipelineTriggerTableRecordsRequest\x1a\x39.core.mgmt.v1beta.ListPipelineTriggerTableRecordsResponse\";\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02%\x12#/v1beta/metrics/vdp/pipeline/tables\x12\xd3\x01\n\x1fListPipelineTriggerChartRecords\x12\x38.core.mgmt.v1beta.ListPipelineTriggerChartRecordsRequest\x1a\x39.core.mgmt.v1beta.ListPipelineTriggerChartRecordsResponse\";\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02%\x12#/v1beta/metrics/vdp/pipeline/charts\x12\xca\x01\n\x1bListConnectorExecuteRecords\x12\x34.core.mgmt.v1beta.ListConnectorExecuteRecordsRequest\x1a\x35.core.mgmt.v1beta.ListConnectorExecuteRecordsResponse\">\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02(\x12&/v1beta/metrics/vdp/connector/executes\x12\xd7\x01\n ListConnectorExecuteTableRecords\x12\x39.core.mgmt.v1beta.ListConnectorExecuteTableRecordsRequest\x1a:.core.mgmt.v1beta.ListConnectorExecuteTableRecordsResponse\"<\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02&\x12$/v1beta/metrics/vdp/connector/tables\x12\xd7\x01\n ListConnectorExecuteChartRecords\x12\x39.core.mgmt.v1beta.ListConnectorExecuteChartRecordsRequest\x1a:.core.mgmt.v1beta.ListConnectorExecuteChartRecordsResponse\"<\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02&\x12$/v1beta/metrics/vdp/connector/charts\x12\x9c\x01\n\x0f\x41uthTokenIssuer\x12(.core.mgmt.v1beta.AuthTokenIssuerRequest\x1a).core.mgmt.v1beta.AuthTokenIssuerResponse\"4\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x1e\"\x19/v1beta/auth/token_issuer:\x01*\x12\x80\x01\n\tAuthLogin\x12\".core.mgmt.v1beta.AuthLoginRequest\x1a#.core.mgmt.v1beta.AuthLoginResponse\"*\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x14\"\x12/v1beta/auth/login\x12\x84\x01\n\nAuthLogout\x12#.core.mgmt.v1beta.AuthLogoutRequest\x1a$.core.mgmt.v1beta.AuthLogoutResponse\"+\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x15\"\x13/v1beta/auth/logout\x12\xa8\x01\n\x12\x41uthChangePassword\x12+.core.mgmt.v1beta.AuthChangePasswordRequest\x1a,.core.mgmt.v1beta.AuthChangePasswordResponse\"7\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02!\"\x1c/v1beta/auth/change_password:\x01*\x12\xba\x01\n\x17\x41uthValidateAccessToken\x12\x30.core.mgmt.v1beta.AuthValidateAccessTokenRequest\x1a\x31.core.mgmt.v1beta.AuthValidateAccessTokenResponse\":\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02$\"\"/v1beta/auth/validate_access_token\x1a\x1a\x92\x41\x17\x12\x15Public Core endpointsB\xcf\x01\n\x14\x63om.core.mgmt.v1betaB\x16MgmtPublicServiceProtoP\x01Z=github.com/instill-ai/protogen-go/core/mgmt/v1beta;mgmtv1beta\xa2\x02\x03\x43MX\xaa\x02\x10\x43ore.Mgmt.V1beta\xca\x02\x10\x43ore\\Mgmt\\V1beta\xe2\x02\x1c\x43ore\\Mgmt\\V1beta\\GPBMetadata\xea\x02\x12\x43ore::Mgmt::V1betab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'core.mgmt.v1beta.mgmt_public_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024com.core.mgmt.v1betaB\026MgmtPublicServiceProtoP\001Z=github.com/instill-ai/protogen-go/core/mgmt/v1beta;mgmtv1beta\242\002\003CMX\252\002\020Core.Mgmt.V1beta\312\002\020Core\\Mgmt\\V1beta\342\002\034Core\\Mgmt\\V1beta\\GPBMetadata\352\002\022Core::Mgmt::V1beta'
  _MGMTPUBLICSERVICE._options = None
  _MGMTPUBLICSERVICE._serialized_options = b'\222A\027\022\025Public Core endpoints'
  _MGMTPUBLICSERVICE.methods_by_name['DeleteOrganizationMembership']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['DeleteOrganizationMembership']._serialized_options = b'\332A\004name\202\323\344\223\002.*,/v1beta/{name=organizations/*/memberships/*}'
  _MGMTPUBLICSERVICE.methods_by_name['Liveness']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['Liveness']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002+\022\022/v1beta/__livenessZ\025\022\023/v1beta/health/mgmt'
  _MGMTPUBLICSERVICE.methods_by_name['Readiness']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['Readiness']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002+\022\023/v1beta/__readinessZ\024\022\022/v1beta/ready/mgmt'
  _MGMTPUBLICSERVICE.methods_by_name['CheckNamespace']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['CheckNamespace']._serialized_options = b'\332A\tnamespace\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002\034\"\027/v1beta/check-namespace:\001*'
  _MGMTPUBLICSERVICE.methods_by_name['GetAuthenticatedUser']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['GetAuthenticatedUser']._serialized_options = b'\332A\020user,update_mask\202\323\344\223\002\016\022\014/v1beta/user'
  _MGMTPUBLICSERVICE.methods_by_name['PatchAuthenticatedUser']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['PatchAuthenticatedUser']._serialized_options = b'\332A\020user,update_mask\202\323\344\223\002\0242\014/v1beta/user:\004user'
  _MGMTPUBLICSERVICE.methods_by_name['ListUsers']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['ListUsers']._serialized_options = b'\202\323\344\223\002\017\022\r/v1beta/users'
  _MGMTPUBLICSERVICE.methods_by_name['GetUser']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['GetUser']._serialized_options = b'\332A\004name\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002\030\022\026/v1beta/{name=users/*}'
  _MGMTPUBLICSERVICE.methods_by_name['ListUserMemberships']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['ListUserMemberships']._serialized_options = b'\332A\006parent\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002&\022$/v1beta/{parent=users/*}/memberships'
  _MGMTPUBLICSERVICE.methods_by_name['GetUserMembership']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['GetUserMembership']._serialized_options = b'\332A\004name\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002&\022$/v1beta/{name=users/*/memberships/*}'
  _MGMTPUBLICSERVICE.methods_by_name['UpdateUserMembership']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['UpdateUserMembership']._serialized_options = b'\332A\026membership,update_mask\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002=\032//v1beta/{membership.name=users/*/memberships/*}:\nmembership'
  _MGMTPUBLICSERVICE.methods_by_name['DeleteUserMembership']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['DeleteUserMembership']._serialized_options = b'\332A\004name\202\323\344\223\002&*$/v1beta/{name=users/*/memberships/*}'
  _MGMTPUBLICSERVICE.methods_by_name['ListOrganizations']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['ListOrganizations']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002\027\022\025/v1beta/organizations'
  _MGMTPUBLICSERVICE.methods_by_name['CreateOrganization']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['CreateOrganization']._serialized_options = b'\332A\014organization\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002%\"\025/v1beta/organizations:\014organization'
  _MGMTPUBLICSERVICE.methods_by_name['GetOrganization']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['GetOrganization']._serialized_options = b'\332A\004name\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002 \022\036/v1beta/{name=organizations/*}'
  _MGMTPUBLICSERVICE.methods_by_name['UpdateOrganization']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['UpdateOrganization']._serialized_options = b'\332A\030organization,update_mask\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002;2+/v1beta/{organization.name=organizations/*}:\014organization'
  _MGMTPUBLICSERVICE.methods_by_name['DeleteOrganization']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['DeleteOrganization']._serialized_options = b'\332A\004name\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002 *\036/v1beta/{name=organizations/*}'
  _MGMTPUBLICSERVICE.methods_by_name['ListOrganizationMemberships']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['ListOrganizationMemberships']._serialized_options = b'\332A\006parent\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002.\022,/v1beta/{parent=organizations/*}/memberships'
  _MGMTPUBLICSERVICE.methods_by_name['GetOrganizationMembership']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['GetOrganizationMembership']._serialized_options = b'\332A\004name\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002.\022,/v1beta/{name=organizations/*/memberships/*}'
  _MGMTPUBLICSERVICE.methods_by_name['UpdateOrganizationMembership']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['UpdateOrganizationMembership']._serialized_options = b'\332A\026membership,update_mask\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002E\0327/v1beta/{membership.name=organizations/*/memberships/*}:\nmembership'
  _MGMTPUBLICSERVICE.methods_by_name['GetAuthenticatedUserSubscription']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['GetAuthenticatedUserSubscription']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002\033\022\031/v1beta/user/subscription'
  _MGMTPUBLICSERVICE.methods_by_name['GetOrganizationSubscription']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['GetOrganizationSubscription']._serialized_options = b'\332A\006parent\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002/\022-/v1beta/{parent=organizations/*}/subscription'
  _MGMTPUBLICSERVICE.methods_by_name['CreateToken']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['CreateToken']._serialized_options = b'\332A\005token\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002\027\"\016/v1beta/tokens:\005token'
  _MGMTPUBLICSERVICE.methods_by_name['ListTokens']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['ListTokens']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002\020\022\016/v1beta/tokens'
  _MGMTPUBLICSERVICE.methods_by_name['GetToken']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['GetToken']._serialized_options = b'\332A\004name\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002\031\022\027/v1beta/{name=tokens/*}'
  _MGMTPUBLICSERVICE.methods_by_name['DeleteToken']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['DeleteToken']._serialized_options = b'\332A\004name\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002\031*\027/v1beta/{name=tokens/*}'
  _MGMTPUBLICSERVICE.methods_by_name['ValidateToken']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['ValidateToken']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002\030\"\026/v1beta/validate_token'
  _MGMTPUBLICSERVICE.methods_by_name['ListPipelineTriggerRecords']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['ListPipelineTriggerRecords']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002\'\022%/v1beta/metrics/vdp/pipeline/triggers'
  _MGMTPUBLICSERVICE.methods_by_name['ListPipelineTriggerTableRecords']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['ListPipelineTriggerTableRecords']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002%\022#/v1beta/metrics/vdp/pipeline/tables'
  _MGMTPUBLICSERVICE.methods_by_name['ListPipelineTriggerChartRecords']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['ListPipelineTriggerChartRecords']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002%\022#/v1beta/metrics/vdp/pipeline/charts'
  _MGMTPUBLICSERVICE.methods_by_name['ListConnectorExecuteRecords']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['ListConnectorExecuteRecords']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002(\022&/v1beta/metrics/vdp/connector/executes'
  _MGMTPUBLICSERVICE.methods_by_name['ListConnectorExecuteTableRecords']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['ListConnectorExecuteTableRecords']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002&\022$/v1beta/metrics/vdp/connector/tables'
  _MGMTPUBLICSERVICE.methods_by_name['ListConnectorExecuteChartRecords']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['ListConnectorExecuteChartRecords']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002&\022$/v1beta/metrics/vdp/connector/charts'
  _MGMTPUBLICSERVICE.methods_by_name['AuthTokenIssuer']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['AuthTokenIssuer']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002\036\"\031/v1beta/auth/token_issuer:\001*'
  _MGMTPUBLICSERVICE.methods_by_name['AuthLogin']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['AuthLogin']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002\024\"\022/v1beta/auth/login'
  _MGMTPUBLICSERVICE.methods_by_name['AuthLogout']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['AuthLogout']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002\025\"\023/v1beta/auth/logout'
  _MGMTPUBLICSERVICE.methods_by_name['AuthChangePassword']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['AuthChangePassword']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002!\"\034/v1beta/auth/change_password:\001*'
  _MGMTPUBLICSERVICE.methods_by_name['AuthValidateAccessToken']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['AuthValidateAccessToken']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002$\"\"/v1beta/auth/validate_access_token'
  _globals['_MGMTPUBLICSERVICE']._serialized_start=257
  _globals['_MGMTPUBLICSERVICE']._serialized_end=7137
# @@protoc_insertion_point(module_scope)



# generated by datamodel-codegen:
#   filename:  googlesearch_task_search_input.json

from __future__ import annotations

from dataclasses import dataclass
from typing import Optional


@dataclass
class Input:
    query: str
    include_link_html: Optional[bool] = False
    include_link_text: Optional[bool] = False
    top_k: Optional[int] = 10



# generated by datamodel-codegen:
#   filename:  googlecloudstorage_task_upload_input.json

from __future__ import annotations

from dataclasses import dataclass


@dataclass
class Input:
    data: str
    object_name: str



# generated by datamodel-codegen:
#   filename:  image_task_draw_semantic_segmentation_input.json

from __future__ import annotations

from dataclasses import dataclass
from typing import List, Optional


@dataclass
class Object:
    category: str
    rle: str


@dataclass
class Input:
    image: str
    stuffs: List[Object]
    showScore: Optional[bool] = None



# generated by datamodel-codegen:
#   filename:  instill_task_text_generation_chat_input.json

from __future__ import annotations

from dataclasses import dataclass
from enum import Enum
from typing import Any, Dict, List, Optional


@dataclass
class ImageUrl:
    url: str


class Type(Enum):
    text = 'text'
    image_url = 'image_url'


@dataclass
class ContentItem:
    type: Type
    image_url: Optional[ImageUrl] = None
    text: Optional[str] = None


@dataclass
class ChatMessage:
    content: List[ContentItem]
    role: str


@dataclass
class Input:
    model_name: str
    prompt: str
    chat_history: Optional[List[ChatMessage]] = None
    extra_params: Optional[Dict[str, Any]] = None
    max_new_tokens: Optional[int] = 50
    prompt_images: Optional[List[str]] = None
    seed: Optional[int] = None
    system_message: Optional[str] = 'You are a helpful assistant.'
    temperature: Optional[float] = 0.7
    top_k: Optional[int] = 10
